@@ -43,10 +43,24 @@ use version 0.77;
 
 # PODNAME: Pod::Weaver::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = 'v0.3.1'; # VERSION
+our $VERSION = 'v0.3.2'; # VERSION
 
 use Pod::Weaver::Config::Assembler;
 
+#   `AutoPrereqs` hints:
+use Pod::Weaver::PluginBundle::CorePrep qw{};
+use Pod::Weaver::Plugin::SingleEncoding qw{};
+use Pod::Weaver::Plugin::Transformer    qw{};
+use Pod::Weaver::Section::Authors       qw{};
+use Pod::Weaver::Section::Collect       qw{};
+use Pod::Weaver::Section::Generic       qw{};
+use Pod::Weaver::Section::Leftovers     qw{};
+use Pod::Weaver::Section::Legal         qw{};
+use Pod::Weaver::Section::Name          qw{};
+use Pod::Weaver::Section::Region        qw{};
+use Pod::Weaver::Section::Version       qw{};
+use Pod::Elemental::Transformer::List   qw{};
+
 sub _p($) {
     my ( $pkg ) = @_;
     return Pod::Weaver::Config::Assembler->expand_package( $pkg );
@@ -155,7 +169,7 @@ Pod::Weaver::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version v0.3.1, released on 2015-10-02 21:08 UTC.
+Version v0.3.2, released on 2015-10-07 13:38 UTC.
 
 =head1 WHAT?
 
